==> deepin-boot-maker_2.0.4.4.orig.tar.xz: deepin-boot-maker-2.0.4.4/src/translations/deepin-boot-maker_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation>無法使用 %1 命令。</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation>磁碟機格式化錯誤：請將磁碟機格式化為 FAT32</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation>磁碟機空間不足：請確保磁碟機有 %1 可用空間</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation>磁碟機掛載錯誤：請再次插入磁碟機或是重新啟動系統</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation>映像檔解壓縮錯誤：請檢查映像檔 md5 校驗和並確保映像檔完整</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation>內部錯誤</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin 開機碟製作器</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation>請選擇一個 ISO 檔案</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation>拖拽 ISO 檔案到此</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation>或是</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation>選擇一個 ISO 檔案</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="156"/>
        <source>Reselect an ISO image file</source>
        <translation>重新選擇 ISO 檔案</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation>正在製作</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation>正在製作，請稍候…</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation>製作期間請勿移除磁碟機或關閉電腦</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="39"/>
        <source>Removable Disk</source>
        <translation>卸除式磁碟機</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="108"/>
        <source>Removable disk</source>
        <translation>卸除式磁碟機</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin 開機碟製作器</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation>立刻重新啟動</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation>製作成功</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation>回報會自動上傳錯誤紀錄。沒有你的回饋與支持我們無法進步</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation>回報</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation>抱歉，製作失敗</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation>製作失敗</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation>請選擇磁碟機</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formating disk can increase the making success rate</source>
        <translation>格式化磁碟機能提高製作成功率</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation>找不到磁碟機</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation>開始製作</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely  deleted by formating, please confirm and continue</source>
        <translation>格式化會清除磁碟機的所有資料，請確認後再繼續</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_2.0.4.9.orig.tar.xz: deepin-boot-maker-2.0.4.9/src/translations/deepin-boot-maker_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="64"/>
        <source>Failed to call the command %1.</source>
        <translation>執行 %1 命令失敗。</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="66"/>
        <source>Disk Format Error: Please format the disk with FAT32</source>
        <translation>磁碟機格式化錯誤：請將磁碟機格式化為 FAT32</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="68"/>
        <source>Insufficient Disk Space: Please ensure that the disk has %1 free space</source>
        <translation>磁碟機空間不足：請確保磁碟機有 %1 可用空間</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="70"/>
        <source>Disk Mount Error: Please plug in the disk again or reboot the system to retry</source>
        <translation>磁碟機掛載錯誤：請再次插入磁碟機或是重新啟動系統</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="72"/>
        <source>Image Uncompress Error: Please check the md5 checksum of the image and ensure the image is complete</source>
        <translation>映像檔解壓縮錯誤：請檢查映像檔 md5 校驗和並確保映像檔完整</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bootmaker.cpp" line="74"/>
        <source>Internal Error</source>
        <translation>內部錯誤</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="117"/>
        <source>Deepin Boot Maker is a simple tool to write system image file into CD/DVD, USB drive and other installation medias.</source>
        <translation>Deepin 開機碟製作器是一個將系統映像檔寫入 CD/DVD、USB 碟、和其他安裝媒體的簡單工具。</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="119"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin 開機碟製作器</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="46"/>
        <source>Please select an ISO image file</source>
        <translation>請選擇一個 ISO 檔案</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="68"/>
        <source>Drag an ISO image file and drop it here</source>
        <translation>拖拽 ISO 檔案到此</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="72"/>
        <source>OR</source>
        <translation>或是</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="84"/>
        <source>Select an ISO image file</source>
        <translation>選擇一個 ISO 檔案</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="102"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="162"/>
        <source>Reselect an ISO image file</source>
        <translation>重新選擇 ISO 檔案</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="44"/>
        <source>Making</source>
        <translation>正在製作</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Making the disk, please wait...</source>
        <translation>正在製作，請稍候…</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Please do not remove the disk or shut down the computer when making</source>
        <translation>製作期間請勿移除磁碟機或關閉電腦</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>卸除式磁碟機</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="118"/>
        <source>Removable disk</source>
        <translation>卸除式磁碟機</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="116"/>
        <source>Deepin Boot Maker</source>
        <translation>Deepin 開機碟製作器</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="86"/>
        <source>Reboot now</source>
        <translation>立刻重新啟動</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Make Successfully</source>
        <translation>製作成功</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="122"/>
        <source>The error log will be uploaded automatically with feedback. We can not improve without your feedback and support</source>
        <translation>意見回應將會自動上傳錯誤紀錄。沒有你的意見回應與支持，我們無法進步</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="123"/>
        <source>Feedback</source>
        <translation>意見回應</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Close</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="145"/>
        <source>Sorry, making failed</source>
        <translation>抱歉，製作失敗</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="146"/>
        <source>Making failed</source>
        <translation>製作失敗</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="79"/>
        <source>Please select a disk</source>
        <translation>請選擇磁碟機</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="102"/>
        <source>Formatting disk can increase the making success rate</source>
        <translation>格式化磁碟可以提高製作成功率</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="124"/>
        <source>No available disk found</source>
        <translation>找不到磁碟機</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="136"/>
        <source>Start making</source>
        <translation>開始製作</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>The disk data will be completely deleted by formatting, please confirm and continue</source>
        <translation>格式化將完全刪除硬碟資料，請確認後繼續</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Format USB flash drive</source>
        <translation>格式化 USB 磁碟機</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="233"/>
        <source>All data will be lost during formatting, please back up in advance and then press OK button.</source>
        <translation>格式化將會刪除所有資料，請提前備份並按下「確認」按鈕。</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="234"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="235"/>
        <source>Ok</source>
        <translation>確認</translation>
    </message>
</context>
</TS>
